/*
 * See Licensing and Copyright notice in naev.h
 */
#pragma once

void opt_menu (void);
void opt_resize (void);
int opt_setVideoMode( int w, int h, int fullscreen, int confirm );
